pub struct ChannelCursor(/* private fields */);Expand description
Opaque cursor used by clients to resume channel delivery.
Cursors currently wrap the last seen event id. Clients should pass them back unchanged instead of interpreting them.
Implementations
Sourceimpl ChannelCursor
impl ChannelCursor
Sourcepub fn new(id: ChannelEventId) -> Self
pub fn new(id: ChannelEventId) -> Self
Creates a cursor after the given event id.
Sourcepub fn event_id(self) -> ChannelEventId
pub fn event_id(self) -> ChannelEventId
Returns the event id represented by this cursor.